pub struct EguiPainter { /* private fields */ }Expand description
The EGUI painter is a complete EGUI integration for use within demos.
It maintains internal state for rendering directly to the swapchain image, and processing Winit events.
Implementations
Sourceimpl EguiPainter
impl EguiPainter
pub fn new(graphics: &Graphics, window: &Window) -> Result<Self>
Sourcepub fn on_window_event(
&mut self,
window: &Window,
event: &WindowEvent,
) -> EventResponse
pub fn on_window_event( &mut self, window: &Window, event: &WindowEvent, ) -> EventResponse
Processes a window event so the UI will respond to clicks and keystrokes.
Sourcepub fn rebuild_swapchain_resources(&mut self, gfx: &Graphics) -> Result<()>
pub fn rebuild_swapchain_resources(&mut self, gfx: &Graphics) -> Result<()>
Checks for compatibility with the swapchain and rebuilds resources if needed.
Sourcepub unsafe fn draw(&mut self, gfx: &Graphics, frame: &Frame) -> Result<()>
pub unsafe fn draw(&mut self, gfx: &Graphics, frame: &Frame) -> Result<()>
Draws the EGUI UI to the currently bound color attachment.
Safety
- This function assumes that a render pass is already started (dynamic or not)
- This function assumes that the color attachment 0 is either a swapchain image or an image with the same dimensions and format.
- This function assumes that the viewport has already been set.
pub fn run( &mut self, gfx: &Graphics, window: &Window, run_ui: impl FnMut(&Context), ) -> Result<()>